..
    This file is part of Invenio.
    Copyright (C) 2015 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

===================================
 Invenio Digital Library Framework
===================================

.. image:: https://img.shields.io/travis/inveniosoftware/invenio.svg
        :target: https://travis-ci.org/inveniosoftware/invenio

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio.svg
        :target: https://github.com/inveniosoftware/invenio/releases

.. image:: https://img.shields.io/pypi/dm/invenio.svg
        :target: https://pypi.python.org/pypi/invenio

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio.svg
        :target: https://github.com/inveniosoftware/invenio/blob/master/LICENSE

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/inveniosoftware/invenio?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

Invenio is a free software suite enabling you to run your own digital
library or document repository on the web.  The technology offered by
the software covers all aspects of digital library management, from
document ingestion through classification, indexing, and curation up
to document dissemination.  Invenio complies with standards such as
the Open Archives Initiative and uses MARC 21 as its underlying
bibliographic format.  The flexibility and performance of Invenio make
it a comprehensive solution for management of document repositories of
moderate to large sizes.

Invenio has been originally developed at CERN to run the CERN document
server, managing over 1,000,000 bibliographic records in high-energy
physics since 2002, covering articles, books, journals, photos,
videos, and more.  Invenio is nowadays co-developed by an
international collaboration comprising institutes such as CERN, DESY,
EPFL, FNAL, SLAC and is being used by many more scientific
institutions worldwide.

We aim at user friendliness and speed.  Among the features are:

- Navigable collection tree

  - Documents organised in collections
  - Regular and virtual collection trees
  - Customisable portal pages for each collection
  - At CERN, over 1,000,000 documents in 700 collections

- Powerful search engine

  - Specially designed indexes to provide fast search speed
    for repositories of up to 3,000,000 records
  - Customisable simple and advanced search interfaces
  - Combined metadata, fulltext and citation search in one go
  - Results clustering by collection

- Flexible metadata

  - Standard metadata format (MARC)
  - Handling articles, books, theses, photos, videos, museum objects
    and more
  - Customisable batch import and web submission workflows
  - Customisable output format display and linking rules

- Collaborative features and personalisation

  - User-defined document baskets
  - User-defined email notification alerts
  - Personalised RSS queries
  - Sharing documents of interest in user groups
  - Peer reviewing and group commenting on documents

Invenio is free software licenced under the terms of the GNU General
Public Licence (GPL).  It is provided on an "as is" basis, in the hope
that it will be useful, but without any warranty.  There is a
possibility to get commercial support in case of interest.

Invenio runs on Unix-like systems and requires MySQL database server
and Apache/Python web application server.  Please consult the INSTALL
file for more information.

Happy hacking and thanks for flying Invenio.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   Github: http://github.com/inveniosoftware
|   URL: http://invenio-software.org
